"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShowWhenNotAuthenticated = exports.ShowWhenAuthenticated = void 0;
const react_1 = __importStar(require("react"));
const AuthContext_1 = __importDefault(require("./AuthContext"));
const ConfigContext_1 = __importDefault(require("./ConfigContext"));
const orderingCore = __importStar(require("@orderingstack/ordering-core"));
const refreshStorageHandler = {
    getRefreshToken: (tenant) => {
        return (window.localStorage.getItem(`orderingstack_${tenant}_refreshToken`) || "");
    },
    setRefreshToken: (tenant, token) => {
        window.localStorage.setItem(`orderingstack_${tenant}_refreshToken`, token);
    },
    clearRefreshToken: (tenant) => {
        window.localStorage.removeItem(`orderingstack_${tenant}_refreshToken`);
    },
};
function AuthWrapper(props) {
    const _configContext = react_1.useContext(ConfigContext_1.default);
    if (!_configContext) {
        return react_1.default.createElement(react_1.Fragment, null, "Configuration shoud be provided");
    }
    const config = _configContext;
    const [auth, setAuth] = react_1.useState({
        loggedIn: false,
        UUID: "",
    });
    function onSignOut() {
        console.log("--- log out ----");
        setAuth({ loggedIn: false, UUID: "" });
        orderingCore.clearAuthData(config.tenant, refreshStorageHandler);
    }
    function hasValidRoles(acceptedRolesArray, roles) {
        if (!acceptedRolesArray || acceptedRolesArray.length === 0) {
            return true;
        }
        const authorities = roles.map((r) => r.role);
        const rolesIntersection = acceptedRolesArray.filter((value) => authorities.includes(value));
        const isAuthorized = rolesIntersection.length > 0; //authorities.includes(role);
        return isAuthorized;
    }
    function getUserData(baseUrl, authProvider, setAuth) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { UUID, token } = yield authProvider();
                if (token) {
                    const userData = yield orderingCore.getLoggedUserData(baseUrl, token);
                    if (!hasValidRoles(props.roles, userData.roles)) {
                        console.log("--- USER HAS NO REQUIRED ROLES ----- ");
                        onSignOut();
                    }
                    setAuth({
                        loggedIn: true,
                        email: userData.login,
                        UUID: UUID,
                        authProvider: authProvider,
                        signOut: onSignOut,
                    });
                }
            }
            catch (err) {
                onSignOut();
            }
        });
    }
    react_1.useEffect(() => {
        //console.log("AutWrapper init --- ");
        const authProvider = orderingCore.createAuthDataProvider({
            BASE_URL: config.baseUrl,
            TENANT: config.tenant,
            BASIC_AUTH: config.basicAuth,
            anonymousAuth: config.anonymousOnInit,
        }, refreshStorageHandler, false);
        getUserData(config.baseUrl, authProvider, setAuth);
        window.addEventListener("message", function (event) {
            if (event.origin !== config.baseUrl)
                return;
            const authData = event.data;
            console.log(authData);
            if (authData.UUID === "") {
                setAuth({ loggedIn: false, UUID: "" });
            }
            else {
                orderingCore.setAuthData(config.tenant, {
                    UUID: authData.UUID,
                    access_token: authData.access_token,
                    refresh_token: authData.refresh_token,
                    expires_in: authData.expires_in,
                }, refreshStorageHandler);
                setAuth({
                    loggedIn: true,
                    UUID: authData.UUID,
                    authProvider: authProvider,
                    signOut: onSignOut,
                });
                getUserData(config.baseUrl, authProvider, setAuth);
            }
        });
    }, []);
    return (react_1.default.createElement(react_1.Fragment, null,
        react_1.default.createElement(AuthContext_1.default.Provider, { value: auth }, props.children)));
}
exports.default = AuthWrapper;
function ShowWhenAuthenticated(props) {
    const { loggedIn } = react_1.useContext(AuthContext_1.default);
    return loggedIn ? react_1.default.createElement(react_1.Fragment, null, props.children) : null;
}
exports.ShowWhenAuthenticated = ShowWhenAuthenticated;
function ShowWhenNotAuthenticated(props) {
    const { loggedIn } = react_1.useContext(AuthContext_1.default);
    return !loggedIn ? react_1.default.createElement(react_1.Fragment, null, props.children) : null;
}
exports.ShowWhenNotAuthenticated = ShowWhenNotAuthenticated;
/**
 V 1. pobieranie danych uzytkownika po zalogowaniu
 V 2. poprawna obsługa przeładowania (wczytanie tokenu z storage)
 V 3. porpawna usługa --need to login--
 V 4. okreslanie czy nasłuchujemy jako kds czy zwykły user
 V 5. logout - usuniecie wpisu ze storage
 * 6. wsparcie dla logowania anonimowego
 *
 */
